==> dustrac_2.0.5.orig.tar.gz: DustRacing2D-2.0.5/src/editor/translations/dustrac-editor_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU" sourcelanguage="en">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About Dust Racing</source>
        <translation>О Dust Racing</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&apos;</source>
        <translation>&apos;</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Восстановить</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Редактировать</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Сохранить</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <source>A new track &apos;%1&apos; created. Columns: %2, Rows: %3.</source>
        <translation>Новая трасса %1 создана. Колонок: %2; Строк: %3.</translation>
    </message>
    <message>
        <source>Set route: not a valid track.</source>
        <translation>Настройки трассы: трасса не правильны.</translation>
    </message>
    <message>
        <source>Setting the route defines checkpoints for the cars so
that no shortcuts can be taken. It also defines
driving lines for the computer players.

Click on the tiles one by one and make a closed loop
with the target nodes. You can adjust the nodes afterwads.
Start from the first tile after the finish line tile
to make the lap detection and timing work correctly.
Click on the first node again to finish.</source>
        <translation>Определяя направляющую вы устанавливаете контрольные пункты для машин и делите направляющую на маленькие отрезки, которые должны быть пройдены.
Также направляющая задает линию движения машин под управлением компьютера.
Щелкая на знакоместах(тайлах) один за одним сделайте замкнутую петлю с целевыми узлами.
Вы можете отрегулировать узлы позже.
Отмечается Старт на стартовом знакоместе и Финиш на финишном для верного подсчета кругов и времени.
Щелкните на первом узле снова для того чтобы закончить(замкнуть направляющую линию).</translation>
    </message>
    <message>
        <source>Track &apos;%1&apos; opened.</source>
        <translation>Трасса »%1« открыта.</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;О</translation>
    </message>
    <message>
        <source>&amp;Route</source>
        <translation>&amp;Направляющая</translation>
    </message>
    <message>
        <source>Erase object</source>
        <translation>Стереть объект</translation>
    </message>
    <message>
        <source>Index set to &apos;%1&apos;.</source>
        <translation type="vanished">Значение индекса установлено в %1.</translation>
    </message>
    <message>
        <source>Choose &apos;File -&gt; New&apos; or &apos;File -&gt; Open&apos; to start.</source>
        <translation>Для начала работы выбрать в меню: &quot;Файл&quot; &gt; &quot;Новый&quot; или &quot;Файл&quot; &gt; &quot;Открыть&quot;.</translation>
    </message>
    <message>
        <source>Set route, checkpoints and driving lines.</source>
        <translation>Установите контрольные точки и направляющие линии движения ИИ.</translation>
    </message>
    <message>
        <source>Enlarge ver size</source>
        <translation>Увеличить по вертикали</translation>
    </message>
    <message>
        <source>Randomly rotate objects</source>
        <translation>Случайно поворачивать объекты</translation>
    </message>
    <message>
        <source>Scale:</source>
        <translation>Масштаб:</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Выбрать</translation>
    </message>
    <message>
        <source>Scale set to %1%</source>
        <translation>Установлен масштаб в %1% процентов</translation>
    </message>
    <message>
        <source>Open a track</source>
        <translation>Открыть трассу</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Открыть …</translation>
    </message>
    <message>
        <source>Set route</source>
        <translation>Установть направляющую</translation>
    </message>
    <message>
        <source>Clear &amp;route</source>
        <translation>Очистить &amp;направляющую</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>О &amp;Qt</translation>
    </message>
    <message>
        <source>ERROR!!: Cannot load objects from &apos;</source>
        <translation>Ошибка! Не получилось загрузить объекты из: &apos;</translation>
    </message>
    <message>
        <source>Save a track</source>
        <translation>Сохранить трассу</translation>
    </message>
    <message>
        <source>&amp;Save as...</source>
        <translation>Сохранить &amp;как …</translation>
    </message>
    <message>
        <source>&apos; saved.</source>
        <translation>&apos; сохранено.</translation>
    </message>
    <message>
        <source>Loading &apos;%1&apos;..</source>
        <translation>Загрузка: %1 …</translation>
    </message>
    <message>
        <source>ERROR!!: %1 doesn&apos;t exist.</source>
        <translation>Ошибка! %1 не найдено.</translation>
    </message>
    <message>
        <source>Save your work to correct location.</source>
        <translation>Сохраняйте ваши наработки в корректное место.</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>О Qt</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Новый</translation>
    </message>
    <message>
        <source>&amp;Clear all</source>
        <translation type="vanished">Очистить &amp;всё</translation>
    </message>
    <message>
        <source>Track &apos;</source>
        <translation>Трасса &apos;</translation>
    </message>
    <message>
        <source>&amp;Set route..</source>
        <translation>Установить &amp;трассу …</translation>
    </message>
    <message>
        <source>New file</source>
        <translation>Новый файл</translation>
    </message>
    <message>
        <source>Track Files (*.trk)</source>
        <translation>Файлы трасс (*.trk)</translation>
    </message>
    <message>
        <source>Invalid track. Route cannot be set.</source>
        <translation>Некоректная трасса. Направляющая не может быть привязана.</translation>
    </message>
    <message>
        <source>Failed to open track &apos;</source>
        <translation>Не удалось открыть трассу: &apos;</translation>
    </message>
    <message>
        <source>Failed to save track as &apos;</source>
        <translation>Не удалось сохранить трассу как: &apos;</translation>
    </message>
    <message>
        <source>To make the game find your circuits, save them to %1%2%3%2</source>
        <translation>Для того чтобы игра могла загрузить ваши трассы, сохраняйте их сюда: %1%2%3%2</translation>
    </message>
    <message>
        <source>Failed to save track &apos;</source>
        <translation>Не удалось сохранить трассу: &apos;</translation>
    </message>
    <message>
        <source>Enlarge hor size</source>
        <translation>Увеличить по горизонтали</translation>
    </message>
    <message>
        <source>&amp;Set properties..</source>
        <translation>&amp;Установить свойства …</translation>
    </message>
    <message>
        <source>Set route: route finished.</source>
        <translation>Установить свойство направляющей: Конец.</translation>
    </message>
    <message>
        <source>Set route: begin.</source>
        <translation>Установить свойство направляющей: Начало.</translation>
    </message>
    <message>
        <source>Track properties updated.</source>
        <translation>Свойства трассы обновлены</translation>
    </message>
</context>
<context>
    <name>NewTrackDialog</name>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Number of tile columns:</source>
        <translation>Количество колонок:</translation>
    </message>
    <message>
        <source>Create a new track</source>
        <translation>Создать новую трассу</translation>
    </message>
    <message>
        <source>Track name:</source>
        <translation>Имя трассы:</translation>
    </message>
    <message>
        <source>Number of tile rows:</source>
        <translation>Количество строк:</translation>
    </message>
    <message>
        <source>User track:</source>
        <translation>Пользовательская трасса:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Tiles cleared.</source>
        <translation type="vanished">Знакоместа(тайлы) очищены.</translation>
    </message>
    <message>
        <source>Route cleared.</source>
        <translation>Трасса очищена.</translation>
    </message>
</context>
<context>
    <name>QWidget</name>
    <message>
        <source> CW..</source>
        <translation> по часовой стрелке..</translation>
    </message>
    <message>
        <source> CCW..</source>
        <translation> против часовой стрелки..</translation>
    </message>
    <message>
        <source>Set computer hint &apos;brake hard&apos;..</source>
        <translation>Установить подсказку для ИИ &quot;Тормозить в пол&quot;..</translation>
    </message>
    <message>
        <source>Rotate..</source>
        <translation>Повернуть..</translation>
    </message>
    <message>
        <source>Set size..</source>
        <translation>Установить размер..</translation>
    </message>
    <message>
        <source>Clear computer hint</source>
        <translation>Снять подсказку для ИИ</translation>
    </message>
    <message>
        <source>Rotate 90</source>
        <translation>Повернуть на 90</translation>
    </message>
    <message>
        <source>Set computer hint &apos;brake&apos;..</source>
        <translation>Установить подсказку для ИИ &quot;Притормозить&quot;..</translation>
    </message>
    <message>
        <source>Insert row..</source>
        <translation>Вставить строку..</translation>
    </message>
    <message>
        <source>Delete row..</source>
        <translation>Удалить строку..</translation>
    </message>
    <message>
        <source>Insert column..</source>
        <translation>Вставить колонку..</translation>
    </message>
    <message>
        <source>Delete column..</source>
        <translation>Удалить колонку..</translation>
    </message>
    <message>
        <source>Exclude from minimap</source>
        <translation>Исключить из мини карты</translation>
    </message>
    <message>
        <source>Insert row before..</source>
        <translation>Вставить строку перед..</translation>
    </message>
    <message>
        <source>Insert row after..</source>
        <translation>Вставить строку после..</translation>
    </message>
    <message>
        <source>Insert column before..</source>
        <translation>Вставить колонку перед..</translation>
    </message>
    <message>
        <source>Insert column after..</source>
        <translation>Вставить колонку после..</translation>
    </message>
    <message>
        <source>Force stationary</source>
        <translation>Сделать неподвижными</translation>
    </message>
</context>
<context>
    <name>RotateDialog</name>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Angle in degrees:</source>
        <translation>Угол в градусах:</translation>
    </message>
    <message>
        <source>Rotate Object</source>
        <translation>Повернуть объект</translation>
    </message>
</context>
<context>
    <name>TargetNodeSizeDlg</name>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <source>Set target node size</source>
        <translation>Установить размер целевого узла</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Высота:</translation>
    </message>
</context>
<context>
    <name>TrackPropertiesDialog</name>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Set track properties</source>
        <translation>Установить свойства трассы</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Index:</source>
        <translation>Индекс:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Имя:</translation>
    </message>
    <message>
        <source>User track:</source>
        <translation>Трасса добавленна пользователем:</translation>
    </message>
</context>
</TS>

==> dustrac-2.1.1.tar.gz: DustRacing2D-2.1.1/src/editor/translations/dustrac-editor_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU" sourcelanguage="en">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About Dust Racing</source>
        <translation>О Dust Racing</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&apos;</source>
        <translation>&apos;</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Восстановить</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Редактировать</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Сохранить</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <source>A new track &apos;%1&apos; created. Columns: %2, Rows: %3.</source>
        <translation>Новая трасса %1 создана. Колонок: %2; Строк: %3.</translation>
    </message>
    <message>
        <source>Set route: not a valid track.</source>
        <translation>Настройки трассы: трасса не правильны.</translation>
    </message>
    <message>
        <source>Setting the route defines checkpoints for the cars so
that no shortcuts can be taken. It also defines
driving lines for the computer players.

Click on the tiles one by one and make a closed loop
with the target nodes. You can adjust the nodes afterwards.
Start from the first tile after the finish line tile
to make the lap detection and timing work correctly.
Click on the first node again to finish.</source>
        <translation>Определяя направляющую вы устанавливаете контрольные пункты для машин и делите направляющую на маленькие отрезки, которые должны быть пройдены.
Также направляющая задает линию движения машин под управлением компьютера.
Щелкая на знакоместах(тайлах) один за одним сделайте замкнутую петлю с целевыми узлами.
Вы можете отрегулировать узлы позже.
Отмечается Старт на стартовом знакоместе и Финиш на финишном для верного подсчета кругов и времени.
Щелкните на первом узле снова для того чтобы закончить(замкнуть направляющую линию).</translation>
    </message>
    <message>
        <source>Track &apos;%1&apos; opened.</source>
        <translation>Трасса »%1« открыта.</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;О</translation>
    </message>
    <message>
        <source>&amp;Route</source>
        <translation>&amp;Направляющая</translation>
    </message>
    <message>
        <source>Erase object</source>
        <translation>Стереть объект</translation>
    </message>
    <message>
        <source>Index set to &apos;%1&apos;.</source>
        <translation type="vanished">Значение индекса установлено в %1.</translation>
    </message>
    <message>
        <source>Choose &apos;File -&gt; New&apos; or &apos;File -&gt; Open&apos; to start.</source>
        <translation>Для начала работы выбрать в меню: &quot;Файл&quot; &gt; &quot;Новый&quot; или &quot;Файл&quot; &gt; &quot;Открыть&quot;.</translation>
    </message>
    <message>
        <source>Set route, checkpoints and driving lines.</source>
        <translation>Установите контрольные точки и направляющие линии движения ИИ.</translation>
    </message>
    <message>
        <source>Enlarge ver size</source>
        <translation>Увеличить по вертикали</translation>
    </message>
    <message>
        <source>Randomly rotate objects</source>
        <translation>Случайно поворачивать объекты</translation>
    </message>
    <message>
        <source>Scale:</source>
        <translation>Масштаб:</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Выбрать</translation>
    </message>
    <message>
        <source>Scale set to %1%</source>
        <translation>Установлен масштаб в %1% процентов</translation>
    </message>
    <message>
        <source>Open a track</source>
        <translation>Открыть трассу</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Открыть …</translation>
    </message>
    <message>
        <source>Set route</source>
        <translation>Установть направляющую</translation>
    </message>
    <message>
        <source>Clear &amp;route</source>
        <translation>Очистить &amp;направляющую</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>О &amp;Qt</translation>
    </message>
    <message>
        <source>ERROR!!: Cannot load objects from &apos;</source>
        <translation>Ошибка! Не получилось загрузить объекты из: &apos;</translation>
    </message>
    <message>
        <source>Save a track</source>
        <translation>Сохранить трассу</translation>
    </message>
    <message>
        <source>&amp;Save as...</source>
        <translation>Сохранить &amp;как …</translation>
    </message>
    <message>
        <source>&apos; saved.</source>
        <translation>&apos; сохранено.</translation>
    </message>
    <message>
        <source>Loading &apos;%1&apos;..</source>
        <translation>Загрузка: %1 …</translation>
    </message>
    <message>
        <source>ERROR!!: %1 doesn&apos;t exist.</source>
        <translation>Ошибка! %1 не найдено.</translation>
    </message>
    <message>
        <source>Save your work to correct location.</source>
        <translation>Сохраняйте ваши наработки в корректное место.</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>О Qt</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Новый</translation>
    </message>
    <message>
        <source>&amp;Clear all</source>
        <translation type="vanished">Очистить &amp;всё</translation>
    </message>
    <message>
        <source>Track &apos;</source>
        <translation>Трасса &apos;</translation>
    </message>
    <message>
        <source>&amp;Set route..</source>
        <translation>Установить &amp;трассу …</translation>
    </message>
    <message>
        <source>New file</source>
        <translation>Новый файл</translation>
    </message>
    <message>
        <source>Track Files (*.trk)</source>
        <translation>Файлы трасс (*.trk)</translation>
    </message>
    <message>
        <source>Invalid track. Route cannot be set.</source>
        <translation>Некоректная трасса. Направляющая не может быть привязана.</translation>
    </message>
    <message>
        <source>Failed to open track &apos;</source>
        <translation>Не удалось открыть трассу: &apos;</translation>
    </message>
    <message>
        <source>Failed to save track as &apos;</source>
        <translation>Не удалось сохранить трассу как: &apos;</translation>
    </message>
    <message>
        <source>To make the game find your circuits, save them to %1%2%3%2</source>
        <translation>Для того чтобы игра могла загрузить ваши трассы, сохраняйте их сюда: %1%2%3%2</translation>
    </message>
    <message>
        <source>Failed to save track &apos;</source>
        <translation>Не удалось сохранить трассу: &apos;</translation>
    </message>
    <message>
        <source>Enlarge hor size</source>
        <translation>Увеличить по горизонтали</translation>
    </message>
    <message>
        <source>&amp;Set properties..</source>
        <translation>&amp;Установить свойства …</translation>
    </message>
    <message>
        <source>Set route: route finished.</source>
        <translation>Установить свойство направляющей: Конец.</translation>
    </message>
    <message>
        <source>Set route: begin.</source>
        <translation>Установить свойство направляющей: Начало.</translation>
    </message>
    <message>
        <source>Track properties updated.</source>
        <translation>Свойства трассы обновлены</translation>
    </message>
</context>
<context>
    <name>NewTrackDialog</name>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Number of tile columns:</source>
        <translation>Количество колонок:</translation>
    </message>
    <message>
        <source>Create a new track</source>
        <translation>Создать новую трассу</translation>
    </message>
    <message>
        <source>Track name:</source>
        <translation>Имя трассы:</translation>
    </message>
    <message>
        <source>Number of tile rows:</source>
        <translation>Количество строк:</translation>
    </message>
    <message>
        <source>User track:</source>
        <translation>Пользовательская трасса:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Tiles cleared.</source>
        <translation type="vanished">Знакоместа(тайлы) очищены.</translation>
    </message>
    <message>
        <source>Route cleared.</source>
        <translation>Трасса очищена.</translation>
    </message>
</context>
<context>
    <name>QWidget</name>
    <message>
        <source> CW..</source>
        <translation> по часовой стрелке..</translation>
    </message>
    <message>
        <source> CCW..</source>
        <translation> против часовой стрелки..</translation>
    </message>
    <message>
        <source>Set computer hint &apos;brake hard&apos;..</source>
        <translation>Установить подсказку для ИИ &quot;Тормозить в пол&quot;..</translation>
    </message>
    <message>
        <source>Rotate..</source>
        <translation>Повернуть..</translation>
    </message>
    <message>
        <source>Set size..</source>
        <translation>Установить размер..</translation>
    </message>
    <message>
        <source>Clear computer hint</source>
        <translation>Снять подсказку для ИИ</translation>
    </message>
    <message>
        <source>Rotate 90</source>
        <translation>Повернуть на 90</translation>
    </message>
    <message>
        <source>Set computer hint &apos;brake&apos;..</source>
        <translation>Установить подсказку для ИИ &quot;Притормозить&quot;..</translation>
    </message>
    <message>
        <source>Insert row..</source>
        <translation>Вставить строку..</translation>
    </message>
    <message>
        <source>Delete row..</source>
        <translation>Удалить строку..</translation>
    </message>
    <message>
        <source>Insert column..</source>
        <translation>Вставить колонку..</translation>
    </message>
    <message>
        <source>Delete column..</source>
        <translation>Удалить колонку..</translation>
    </message>
    <message>
        <source>Exclude from minimap</source>
        <translation>Исключить из мини карты</translation>
    </message>
    <message>
        <source>Insert row before..</source>
        <translation>Вставить строку перед..</translation>
    </message>
    <message>
        <source>Insert row after..</source>
        <translation>Вставить строку после..</translation>
    </message>
    <message>
        <source>Insert column before..</source>
        <translation>Вставить колонку перед..</translation>
    </message>
    <message>
        <source>Insert column after..</source>
        <translation>Вставить колонку после..</translation>
    </message>
    <message>
        <source>Force stationary</source>
        <translation>Сделать неподвижными</translation>
    </message>
</context>
<context>
    <name>RotateDialog</name>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Angle in degrees:</source>
        <translation>Угол в градусах:</translation>
    </message>
    <message>
        <source>Rotate Object</source>
        <translation>Повернуть объект</translation>
    </message>
</context>
<context>
    <name>TargetNodeSizeDlg</name>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <source>Set target node size</source>
        <translation>Установить размер целевого узла</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Высота:</translation>
    </message>
</context>
<context>
    <name>TrackPropertiesDialog</name>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Set track properties</source>
        <translation>Установить свойства трассы</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Index:</source>
        <translation>Индекс:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Имя:</translation>
    </message>
    <message>
        <source>User track:</source>
        <translation>Трасса добавленна пользователем:</translation>
    </message>
</context>
</TS>
